        integer maxn
	parameter ( maxn = 10000 )
        real*8  wzmin, wzmax, trackl
	real*8  ke(maxn)
	integer indx(maxn)
        integer nevent
        integer outzero
        integer  pjcode, pjsub, pjchg
	integer  tgcode, tgsub, tgchg
        integer  inpfileno, xyz
        real*8   pjpx, pjpy, pjpz
	real*8   tgpx, tgpy, tgpz
        real  xpos, ypos, zpos  
        integer pjmnum, tgmnum  ! proj. target mass number
        record /ptcl/ pj, tg, plab
        common /Zotherc/ pj, tg, plab, ke, wzmin, wzmax, 
     *    trackl, pjpx, pjpy, pjpz, tgpx, tgpy, tgpz,
     *    xpos, ypos, zpos,  
     *    indx, nevent, outzero,
     *    pjmnum, tgmnum, inpfileno, xyz,
     *	  pjcode, pjsub, pjchg,
     *	  tgcode, tgsub, tgchg

	  



	



